#include <cassert>
#include <cstdio>
#include <algorithm>
#include <vector>

struct t_angle {
	inline t_angle(long long dx, long long dy, long long x, long long y): a(x * dx + y * dy), b(x * dy - y * dx), t(x * dx + y * dy > 0), d(x * x + y * y) {}
	inline t_angle() {}
	inline bool operator==(const t_angle &rhs) const { return (t == rhs.t) && (a * rhs.b == rhs.a * b); }
	inline bool operator!=(const t_angle &rhs) const { return (t != rhs.t) || (a * rhs.b != rhs.a * b); }
	inline bool operator<(const t_angle &rhs) const {
		if (t > rhs.t) return false;
		if (t < rhs.t) return true;
		return
		a * rhs.b < rhs.a * b;
	}
	inline bool operator>(const t_angle &rhs) const {
		if (t < rhs.t) return false;
		if (t > rhs.t) return true;
		return
		a * rhs.b > rhs.a * b;
	}
	long long a, b, d;
	bool t;
};

struct t_point {
	inline bool operator==(const t_point &rhs) const {
		return (x == rhs.x) && (y == rhs.y);
	}
	inline bool operator!=(const t_point &rhs) const {
		return (x != rhs.x) || (y != rhs.y);
	}
	long long x, y;
};

std::vector<t_angle> angle[2];
std::vector<t_point> point;
long num_point;
std::vector<long> stack;
std::vector<long> index;
std::vector<long> count;
long num_count;

//Функции для работы с деревом отрезков:

long get(int l, int x, int y, int a) {
	if (a >= y) return count[l]; if (a < x) return 0; return get(2 * l + 2, (y + x) / 2 + 1, y, a) + get(2 * l + 1, x, (y + x) / 2, a);
}

long del(long l, long x, long y, long i) {
	if ((x > i) || (y < i)) return count[l];
	if (x == y) { return count[l] = 0; }
	if (x > y) return 0;
	return count[l] = del(2 * l + 2, (x + y) / 2 + 1, y, i) + del(2 * l + 1, x, (x + y) / 2, i);
}

long gen(long l, long x, long y) {
	if (x == y) { return count[l] = 1; }
	if (x > y) return 0;
	return count[l] = gen(2 * l + 2, (x + y) / 2 + 1, y) + gen(2 * l + 1, x, (x + y) / 2);
}

long get_count(long a) {
	return get(0, 0, num_count - 1, a);
}

long del_count(long i) {
	return del(0, 0, num_count - 1, i);
}

long gen_count() {
	return gen(0, 0, num_count - 1);
}

//...

long test(long a, long b, long *c) {

	long long dx0 = point[b].x - point[a].x, dy0 = point[b].y - point[a].y;
	num_count = 0;
	long ans = 0;
	for (long i = 0; i < num_point; ++ i) {
		long long dx1 = point[i].x - point[a].x, dy1 = point[i].y - point[a].y;
		long long dx2 = point[i].x - point[b].x, dy2 = point[i].y - point[b].y;
		//Пропускаем точки, лежащие на концах заданного отрезка:
		if (((dx1 == 0) && (dy1 == 0)) || ((dx2 == 0) && (dy2 == 0))) {
			++ ans; continue;
		}
		//Выбираем точки, лежащие справа от прямой:
		if (dx1 * dy0 - dy1 * dx0 < 0) {
			continue;
		}
		
		angle[0][i] = t_angle(dx0, dy0, dx1, dy1);
		angle[1][i] = t_angle(dx0, dy0, dx2, dy2);
		stack[num_count] = i;
		++ num_count;
	}
	//Сортируем по углу, между прямой {a, b} и отрезком {b, i}:
	std::sort(&stack[0], &stack[0] + num_count,
	[] (long i1, long i2) {
		if (angle[1][i1] > angle[1][i2])
			return false;
		if (angle[1][i1] < angle[1][i2])
			return true;
		return
		angle[1][i1].d < angle[1][i2].d;
	}
	);
	//Устанавливаем обратные связи:
	for (long i = 0; i < num_count; ++ i) {
		index[stack[i]] = i;
	}
	//Сортируем по углу, между прямой {a, b} и отрезком {a, i}:
	std::sort(&stack[0], &stack[0] + num_count,
	[] (long i1, long i2) {
		if (angle[0][i1] > angle[0][i2])
			return false;
		if (angle[0][i1] < angle[0][i2])
			return true;
		return
		angle[0][i1].d > angle[0][i2].d;
	}
	);
	//Заполняем дерево отрезков:
	gen_count();
	//Выполняем обход по углу:
	long s0 = 0;
	for (long t, i = 0; i < num_count; i = t) {
		long k = stack[i], s = get_count(index[k]);
		del_count(index[k]);
		//Пропускаем дубликаты:
		for (t = i + 1; (t < num_count) && (point[stack[t]] == point[k]); ++ t) {
			++ s;
			del_count(index[stack[t]]);
		}
		if (s > s0) {
			s0 = s; *c = k;
		}
	}
	return ans + s0;
}

int main() {
	//...
	FILE *fid = fopen("input.txt", "rt");
	fscanf(fid, "%lu", &num_point);
	count.resize(4 * num_point); index.resize(num_point); stack.resize(num_point);
	angle[0].resize(num_point);
	angle[1].resize(num_point);
	long num = num_point + 2, a = num_point + 1, b = num_point;
	point.resize(num);
	for (long i = 0; i < num; ++ i) {
		fscanf(fid, "%lli %lli", &point[i].x, &point[i].y);
	}
	fclose(fid);
	//...
	long s0 = -1, s, c0 = 0, c;
	if ((s = test(a, b, &c)) > s0) { s0 = s; c0 = c; }
	if ((s = test(b, a, &c)) > s0) { s0 = s; c0 = c; }
	//...
	fid = fopen("output.txt", "wt");
	fprintf(fid, "%lu", c0);
	fclose(fid);
	//...
	return 0;
}
